<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dist?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

return [

	// D
	'dist_description' => 'Juec d’esquèletrou distribuit embé SPIP 3.',
	'dist_slogan' => 'Esquèletrou predefinit de SPIP 3',
];
